@@ -17,12 +17,27 @@
 # 外呼失败。
 FAILEDOPERATION_CALLOUTFAILED = 'FailedOperation.CallOutFailed'
 
+# 高风险用户，请勿呼叫
+FAILEDOPERATION_CALLEEISBLACKUSER = 'FailedOperation.CalleeIsBlackUser'
+
 # 被叫号码外呼受限。
 FAILEDOPERATION_CALLEEISLIMITED = 'FailedOperation.CalleeIsLimited'
 
 # 主叫号码外呼超频。
 FAILEDOPERATION_CALLEROVERFREQUENCY = 'FailedOperation.CallerOverFrequency'
 
+# 触发默认被叫规则，呼叫盲区
+FAILEDOPERATION_CALLOUTRULEBLINDAREA = 'FailedOperation.CalloutRuleBlindArea'
+
+# 触发默认外呼规则，被叫一段时间内呼叫量
+FAILEDOPERATION_CALLOUTRULEMAXCALLCOUNTCALLEEINTERVALTIME = 'FailedOperation.CalloutRuleMaxCallCountCalleeIntervalTime'
+
+# 触发默认外呼规则，被叫每日最大呼叫量
+FAILEDOPERATION_CALLOUTRULEMAXCALLCOUNTCALLEEPERDAYAPPID = 'FailedOperation.CalloutRuleMaxCallCountCalleePerDayAppID'
+
+# 触发默认外呼规则，不在可外呼时间
+FAILEDOPERATION_CALLOUTRULENOTWORKTIME = 'FailedOperation.CalloutRuleNotWorkTime'
+
 # 当前号码状态不能被修改。
 FAILEDOPERATION_CURSTATENOTALLOWMODIFY = 'FailedOperation.CurStateNotAllowModify'
 
@@ -38,6 +53,9 @@ FAILEDOPERATION_PERMISSIONDENIED = 'FailedOperation.PermissionDenied'
 # 坐席处于忙碌状态。
 FAILEDOPERATION_SEATSTATUSBUSY = 'FailedOperation.SeatStatusBusy'
 
+# 上传文件个数超过限制
+FAILEDOPERATION_UPLOADFILEOVERFLOW = 'FailedOperation.UploadFileOverflow'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -95,6 +113,12 @@ INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 # 账号不存在。
 INVALIDPARAMETERVALUE_ACCOUNTNOTEXIST = 'InvalidParameterValue.AccountNotExist'
 
+# 审批单号不存在。
+INVALIDPARAMETERVALUE_APPLYIDNOTEXIST = 'InvalidParameterValue.ApplyIDNotExist'
+
+# 公司信息已经存在。
+INVALIDPARAMETERVALUE_COMPANYEXIST = 'InvalidParameterValue.CompanyExist'
+
 # 实例不存在。
 INVALIDPARAMETERVALUE_INSTANCENOTEXIST = 'InvalidParameterValue.InstanceNotExist'
 
@@ -110,15 +134,24 @@ INVALIDPARAMETERVALUE_SKILLGROUPERROR = 'InvalidParameterValue.SkillGroupError'
 # 技能组已存在。
 INVALIDPARAMETERVALUE_SKILLGROUPEXIST = 'InvalidParameterValue.SkillGroupExist'
 
+# 待审核单已经超限，暂时不能再提交
+INVALIDPARAMETERVALUE_WAITINGAPPROVALOVERFLOW = 'InvalidParameterValue.WaitingApprovalOverflow'
+
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
+# 套餐包耗尽
+LIMITEXCEEDED_BASEPACKAGEEXPIRED = 'LimitExceeded.BasePackageExpired'
+
 # 超出数量限制。
 LIMITEXCEEDED_OUTOFCOUNTLIMIT = 'LimitExceeded.OutOfCountLimit'
 
 # 不在白名单中。
 OPERATIONDENIED_NOTINWHITELIST = 'OperationDenied.NotInWhiteList'
 
+# 账号已被禁用。
+OPERATIONDENIED_UINDISABLED = 'OperationDenied.UinDisabled'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
